{% if widget._compact == false %}
  {{{widget._ws_selector}}}
{% endif %}
<sly-select-project
    {% if widget._compact == false %}
    :workspace-id="state.{{{widget._ws_selector.widget_id}}}.workspaceId"
    {% else %}
    :workspace-id="data.{{{widget.widget_id}}}.workspaceId"
    {% endif %}
    :project-id.sync="state.{{{widget.widget_id}}}.projectId"
    :options="data.{{{widget.widget_id}}}.options">
</sly-select-project> 