from supervisely.nn.inference.inference import Inference
from supervisely.nn.inference.instance_segmentation.instance_segmentation import (
    InstanceSegmentation
)
from supervisely.nn.inference.object_detection.object_detection import (
    ObjectDetection
)
